@@ -1003,7 +1003,7 @@ class TableInputMapping(SubscriptableDataclass):
     full_path: str = None
     where_operator: str = ''
     days: int = 0
-    column_types: TableColumnTypes = None
+    column_types: List[TableColumnTypes] = None
 
 
 @dataclass
